==========================================================
bisos.gcipher: from debian dpkg to pypi module conversion.
==========================================================

.. contents::
   :depth: 3
..

Overview
========

gcipher: from debian dpkg to pypi module conversion.

Package Documentation At Github
===============================

The information below is a subset of the full of documentation for this
bisos-pip package. More complete documentation is available at:
https://github.com/bisos-pip/gcipher-cs

.. _table-of-contents:

Table of Contents TOC
=====================

-  `Overview <#overview>`__
-  `Package Documentation At
   Github <#package-documentation-at-github>`__
-  `Installation <#installation>`__

   -  `Installation With pip <#installation-with-pip>`__
   -  `Installation With pipx <#installation-with-pipx>`__

-  `Support <#support>`__

Installation
============

The sources for the bisos.gcipher pip package is maintained at:
https://github.com/bisos-pip/gcipher.

The bisos.gcipher pip package is available at PYPI as
https://pypi.org/project/bisos.gcipher

You can install bisos.gcipher with pip or pipx.

Installation With pip
---------------------

If you need access to bisos.gcipher as a python module, you can install
it with pip:

.. code:: bash

   pip install bisos.gcipher

Installation With pipx
----------------------

If you only need access to bisos.gcipher as a command on command-line,
you can install it with pipx:

.. code:: bash

   pipx install bisos.gcipher

The following commands are made available:

-  gcipher

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact
